#!/bin/bash

set -e

target=$1
echo "iqube-install.sh: working on $1"

if [ -z "$target" ]; then
	echo 'usage: iqube-install.sh [target] # target is something like iqube-stable'
	exit 1
fi

webapps="/var/lib/tomcat7/webapps"

if [ -d "$webapps/$target" ]; then
	sudo rm -rf $webapps/$target/WEB-INF/lib
	sudo rm -rf $webapps/$target/WEB-INF/classes/com
	sudo rm -rf $webapps/$target/WEB-INF/classes/org
fi

sudo cp -aRT $webapps/iqube/ $webapps/$target/

cd $webapps/$target/WEB-INF

if [ ! -e "datasources.xml" ]; then
  sudo cp -a datasources.xml.default datasources.xml
  echo "Copied datasources.xml"
fi

# go into classes dir
cd classes

# always reset mondrian properties
sudo cp mondrian.properties.default mondrian.properties

# copy iqportal.properties if not exist
if [ ! -e "iqportal.properties" ]; then
  sudo cp iqportal.properties.default iqportal.properties
  echo "Copied iqportal.properties. You should probably edit this file!: "
  echo "$webapps/$target/WEB-INF/classes/iqportal.properties"
fi

# update log4j.properties to the correct logfile
sudo cp log4j.properties.default log4j.properties

# create the logfile in /var/log/
logfile="/var/log/$target.log"
logfile_escaped=$(echo $logfile | sed -e 's/\//\\\//g')
sudo touch $logfile
sudo chown tomcat7 $logfile
sudo sed -i "s/\/tmp\/iqube.log/$logfile_escaped/g" log4j.properties

